CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
73 lines
1.7 KiB
C++
73 lines
1.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <performance_common.hh>
|
|
|
|
/**
|
|
* @addtogroup stream stream
|
|
* @{
|
|
* @ingroup PerformanceTestStream
|
|
*/
|
|
|
|
class StreamWaitEventBenchmark : public Benchmark<StreamWaitEventBenchmark> {
|
|
public:
|
|
void operator()(Streams stream_type) {
|
|
const StreamGuard stream_guard{stream_type};
|
|
const hipStream_t stream = stream_guard.stream();
|
|
hipEvent_t wait_event{nullptr};
|
|
|
|
HIP_CHECK(hipEventCreate(&wait_event));
|
|
REQUIRE(wait_event != nullptr);
|
|
HIP_CHECK(hipEventRecord(wait_event, stream));
|
|
|
|
TIMED_SECTION(kTimerTypeCpu) {
|
|
HIP_CHECK(hipStreamWaitEvent(stream, wait_event, 0));
|
|
HIP_CHECK(hipStreamSynchronize(stream));
|
|
}
|
|
HIP_CHECK(hipEventDestroy(wait_event));
|
|
}
|
|
};
|
|
|
|
static void RunBenchmark(Streams stream_type) {
|
|
StreamWaitEventBenchmark benchmark{};
|
|
switch (stream_type) {
|
|
case Streams::nullstream:
|
|
benchmark.AddSectionName("null stream");
|
|
break;
|
|
case Streams::created:
|
|
benchmark.AddSectionName("created");
|
|
break;
|
|
default:
|
|
benchmark.AddSectionName("per thread stream");
|
|
}
|
|
benchmark.Run(stream_type);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Executes `hipStreamWaitEvent`:
|
|
* -# Stream types:
|
|
* - `null`
|
|
* - created
|
|
* Test source
|
|
* ------------------------
|
|
* - performance/api/stream/hipStreamWaitEvent.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Performance_hipStreamWaitEvent) {
|
|
Streams stream_type = GENERATE(Streams::nullstream, Streams::created);
|
|
RunBenchmark(stream_type);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group PerformanceTest.
|
|
* @}
|
|
*/
|